.. _ref-API-Utils:
.. currentmodule:: caterva2

Utility classes and variables
=============================

A collection of utility classes and variables that are used throughout the Caterva2 API.

.. currentmodule:: caterva2

Classes
-------

.. autosummary::
   :toctree: autofiles

    BasicAuth

Variables
---------

.. autosummary::
   :toctree: autofiles

   __version__
..    sub_urlbase_default
